==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/CustomMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GetTileImageUriArgsDescriptionMetadata } from "./GetTileImageUriArgsDescriptionMetadata";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { CustomMapImageryDescription } from "./CustomMapImageryDescription";
/**
 * @hidden
 */
export let CustomMapImageryDescriptionMetadata = /*@__PURE__*/ (() => {
    class CustomMapImageryDescriptionMetadata extends Base {
        static b(a) {
            if (CustomMapImageryDescriptionMetadata.a == null) {
                CustomMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CustomMapImageryDescriptionMetadata.c(CustomMapImageryDescriptionMetadata.a);
            }
            if (a.j(CustomMapImageryDescriptionMetadata.a)) {
                return;
            }
            a.y(CustomMapImageryDescriptionMetadata.a);
            GetTileImageUriArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GeographicMapImageryDescriptionMetadata.c(a);
            a.item("GetTileImageUriRef", "EventRef::getTileImageUri");
        }
        static d(a) {
            CustomMapImageryDescriptionMetadata.b(a);
            a.aa("CustomMapImagery", () => new CustomMapImageryDescription());
            a.z("CustomMapImagery", CustomMapImageryDescriptionMetadata.a);
        }
    }
    CustomMapImageryDescriptionMetadata.$t = /*@__PURE__*/ markType(CustomMapImageryDescriptionMetadata, 'CustomMapImageryDescriptionMetadata');
    CustomMapImageryDescriptionMetadata.a = null;
    return CustomMapImageryDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CustomMapImageryDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GetTileImageUriArgsDescriptionMetadata } from "./GetTileImageUriArgsDescriptionMetadata";
import { GeographicMapImageryDescriptionMetadata } from "./GeographicMapImageryDescriptionMetadata";
import { CustomMapImageryDescription } from "./CustomMapImageryDescription";
/**
 * @hidden
 */
export let CustomMapImageryDescriptionMetadata = /*@__PURE__*/ (() => {
    class CustomMapImageryDescriptionMetadata extends Base {
        static b(a) {
            if (CustomMapImageryDescriptionMetadata.a == null) {
                CustomMapImageryDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CustomMapImageryDescriptionMetadata.c(CustomMapImageryDescriptionMetadata.a);
            }
            if (a.k(CustomMapImageryDescriptionMetadata.a)) {
                return;
            }
            a.aa(CustomMapImageryDescriptionMetadata.a);
            GetTileImageUriArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            GeographicMapImageryDescriptionMetadata.c(a);
            a.item("GetTileImageUriRef", "EventRef::getTileImageUri");
        }
        static d(a) {
            CustomMapImageryDescriptionMetadata.b(a);
            a.ac("CustomMapImagery", () => new CustomMapImageryDescription());
            a.ab("CustomMapImagery", CustomMapImageryDescriptionMetadata.a);
        }
    }
    CustomMapImageryDescriptionMetadata.$t = /*@__PURE__*/ markType(CustomMapImageryDescriptionMetadata, 'CustomMapImageryDescriptionMetadata');
    CustomMapImageryDescriptionMetadata.a = null;
    return CustomMapImageryDescriptionMetadata;
})();
